@@ -97,10 +97,25 @@ class TestLocaleClass:
         assert l.territory == 'TW'
         assert l.script == 'Hant'
 
+        l = Locale.parse('zh_CN')
+        assert l.language == 'zh'
+        assert l.territory == 'CN'
+        assert l.script == 'Hans'
+
+        l = Locale.parse('zh_SG')
+        assert l.language == 'zh'
+        assert l.territory == 'SG'
+        assert l.script == 'Hans'
+
         l = Locale.parse('und_AT')
         assert l.language == 'de'
         assert l.territory == 'AT'
 
+        l = Locale.parse('und_UK')
+        assert l.language == 'en'
+        assert l.territory == 'GB'
+        assert l.script is None
+
     def test_get_display_name(self):
         zh_CN = Locale('zh', 'CN', script='Hans')
         assert zh_CN.get_display_name('en') == 'Chinese (Simplified, China)'
@@ -223,6 +238,10 @@ def test_default_locale(os_environ):
     os_environ['LC_MESSAGES'] = 'POSIX'
     assert default_locale('LC_MESSAGES') == 'en_US_POSIX'
 
+    for value in ['C', 'C.UTF-8', 'POSIX']:
+        os_environ['LANGUAGE'] = value
+        assert default_locale() == 'en_US_POSIX'
+
 
 def test_negotiate_locale():
     assert (core.negotiate_locale(['de_DE', 'en_US'], ['de_DE', 'de_AT']) ==
